@@ -94,17 +94,17 @@
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="249"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="246"/>
         <source>Login failed!</source>
         <translation>Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="355"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="352"/>
         <source>Unable to determine cache id!</source>
         <translation>Cache-ID nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="383"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="380"/>
         <source>Unable to determine cache guid!</source>
         <translation>Cache-Guid nicht feststellbar!</translation>
     </message>
@@ -178,23 +178,23 @@
 <context>
     <name>GcParser</name>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="308"/>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="316"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="310"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="318"/>
         <source>Too many caches</source>
         <translation>Zu viele Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="309"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="311"/>
         <source>No caches in this area</source>
         <translation>Keine Caches in dieser Gegend</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="379"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="381"/>
         <source>Error downloading caches</source>
         <translation>Fehler beim Laden der Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="449"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="451"/>
         <source>Error downloading cache info</source>
         <translation>Fehler beim Download der Cache-Info</translation>
     </message>
@@ -349,6 +349,16 @@
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="140"/>
+        <source>This copy of CacheMe has expired and will close in one minute!</source>
+        <translation>Diese Kopie von CacheMe ist abgelaufen und wird in einer Minute geschlossen!</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="143"/>
+        <source>This copy of CacheMe will expire in %1 days!</source>
+        <translation>Diese Kopie von CacheMe läuft in %1 Tagen aus!</translation>
+    </message>
 </context>
 <context>
     <name>MapDialog</name>
@@ -404,7 +414,7 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
     <message>
-        <location filename="../src/mapwidget.cpp" line="305"/>
+        <location filename="../src/mapwidget.cpp" line="307"/>
         <source>Displayed cache data is %1 weeks old!</source>
         <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
     </message>
