@@ -76,7 +76,7 @@ QString Attribute::toString() const {
      { Attribute::Bicycles,
        QObject::tr("Bicycles Allowed"),              QObject::tr("Bicycles Not Allowed") },
      { Attribute::Motorcycles,
-       QObject::tr("Motorcycles Allowed"),           QObject::tr("Motorcacles Not Allowed") },
+       QObject::tr("Motorcycles Allowed"),           QObject::tr("Motorcycles Not Allowed") },
      { Attribute::Quads,
        QObject::tr("Quads Allowed"),                 QObject::tr("Quads Not Allowed") },
      { Attribute::Jeeps,
@@ -144,7 +144,7 @@ QStringList Attribute::iconFile() const {
   const struct { Attribute::Id type; QString str; } tags[] = {
     { Attribute::Dogs,              "dogs" },
     { Attribute::Fee,               "fee" },
-    { Attribute::Rappelling,        "rappeling" },
+    { Attribute::Rappelling,        "rappelling" },
     { Attribute::Boat,              "boat" },
     { Attribute::Scuba,             "scuba" },
     { Attribute::Kids,              "kids" },
@@ -225,6 +225,10 @@ void Log::Type::set(Log::Type::Id id) {
   m_id = id;
 }
 
+bool Log::Type::is(Log::Type::Id id) const {
+  return m_id == id;
+}
+
 QString Log::Type::toString() const {
   int i;
 
@@ -556,7 +560,7 @@ QString Cache::typeIconFile() const {
     { TypeWebcam,      "webcam" },      { TypeEvent,       "event" },
     { TypeLetterbox,   "letterbox" },   { TypeEarthcache,  "earthcache" },
     { TypeWherigo,     "wherigo" },     { TypeMegaEvent,   "megaevent" },
-    { TypeCito,        "cito" },        { TypeUnknown,     "<unknown>" }
+    { TypeCito,        "cito" },        { TypeUnknown,     "unknown" }
   };
 
   for(i=0;(tags[i].type!=TypeUnknown) && (tags[i].type != m_type);i++); 
@@ -599,7 +603,6 @@ void Cache::setContainer(Container::Type val) {
 }
 
 Container Cache::container() const {
-  Q_ASSERT(this->m_container.isSet());
   return this->m_container;
 }
 
@@ -616,9 +619,6 @@ void Cache::setOwner(const QString &owner) {
 }
 
 QString Cache::owner() const {
-  if(m_owner.isNull() || m_owner.isEmpty())
-    return "?";
-
   return m_owner;
 }
 
@@ -713,6 +713,9 @@ CacheList::CacheList(const QString &name) {
   this->m_name = (QString)name;
 }
 
+CacheList::CacheList() {
+}
+
 CacheList::~CacheList() {
 }
 
@@ -732,6 +735,10 @@ QString CacheList::name() {
   return m_name;
 }
 
+void CacheList::setName(const QString &name) {
+  m_name = name;
+}
+
 QList<Cache>::const_iterator CacheList::begin() const {
   return QList<Cache>::begin();
 }
@@ -740,8 +747,25 @@ QList<Cache>::const_iterator CacheList::end() const {
   return QList<Cache>::end();
 }
 
+QList<Cache>::iterator CacheList::begin() {
+  return QList<Cache>::begin();
+}
+
+QList<Cache>::iterator CacheList::end() {
+  return QList<Cache>::end();
+}
+
 void CacheList::clear() {
   qDebug() << __FUNCTION__;
 
   QList<Cache>::clear();
 }
+
+void CacheList::setDate(const QDate &date) {
+  m_date = date;
+}
+
+QDate CacheList::date() const {
+  return m_date;
+}
+
