@@ -6,6 +6,7 @@
 #include <QQueue>
 #include <QDir>
 #include <QVBoxLayout>
+#include <QMenuBar>
 
 #include "cacheproviderplugin.h"
 
@@ -13,14 +14,12 @@ class CacheProvider  : public QObject {
   Q_OBJECT;
 
  public:
-  CacheProvider();
+  CacheProvider(QWidget *parent = 0);
   ~CacheProvider();
   void requestOverview(const QGeoBoundingBox &);
   void requestInfo(const QString &);
   void requestDetail(const QString &);
-  void next();
-  void done();
-  void start();
+  void start(QWidget * = 0);
   void pluginConfig(QDialog *, QVBoxLayout *);
 
   // functions redirected at current plugin
@@ -30,20 +29,28 @@ class CacheProvider  : public QObject {
   void processRequestInfo(const QString &);
   void processRequestDetail(const QString &);
 
+  void createMenu(QMenuBar *);
+
+ public slots:
+  void next();
+  void done();
+
+ private slots:
   void emitReplyOverview(const CacheList &);
   void emitReplyInfo(const Cache &);
   void emitReplyDetail(const Cache &);
   void emitReplyError(const QString &);
-  void emitSettingsChanged();
-  void emitBusy(bool);
+  void emitReload();
+  void emitNotifyBusy(bool);
+  void providerSelected(QAction *);
 
  signals:
   void replyOverview(const CacheList &);
   void replyInfo(const Cache &);
   void replyDetail(const Cache &);
   void replyError(const QString &);    // any request can emit a error
-  void settingsChanged();
-  void busy(bool);
+  void reload();
+  void notifyBusy(bool);
 
  public:
 
@@ -91,6 +98,7 @@ class CacheProvider  : public QObject {
   // list of available cache provider plugins
   QList <CacheProviderPlugin *> m_cacheProviderPluginList;
   CacheProviderPlugin *m_currentPlugin;
+  QWidget *m_parent;
 };
 
 #endif // CACHEPROVIDER_H
