@@ -9,9 +9,7 @@
 #include <QSvgRenderer>
 #include <QGeoPositionInfo>
 
-#ifndef Q_WS_WIN
 #include <QCompass>
-#endif
 
 QTM_USE_NAMESPACE
 
@@ -29,9 +27,7 @@ class Compass : public QWidget {
 
  public slots:
   void setPosition(const QGeoPositionInfo &);
-#ifndef Q_WS_WIN
   void setPosition(const QCompassReading *);
-#endif
   void timerExpired();
 
  private:
