@@ -44,7 +44,7 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
   QSettings settings;
   settings.beginGroup(name);
   resize(settings.value("size", QSize(640, 480)).toSize());
-  move(settings.value("pos", QPoint(200, 200)).toPoint());
+  move(settings.value("pos", QPoint(0, 0)).toPoint());
   settings.endGroup();
 #endif
 
@@ -66,14 +66,14 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
 
   setAttribute(Qt::WA_DeleteOnClose);
 
-#ifdef Q_OS_SYMBIAN
-  // under Symbian only one entity can grab the media keys. We let the map get them
-  if(!parent) {
-    QT_TRAP_THROWING(iInterfaceSelector = CRemConInterfaceSelector::NewL());
-    QT_TRAP_THROWING(iCoreTarget = CRemConCoreApiTarget::NewL(*iInterfaceSelector, *this));
-    iInterfaceSelector->OpenTargetL();
+  if(parent) {
+    // parent widget must be a window
+    CustomWindow *parentWin = static_cast<CustomWindow *>(parent);
+    Q_ASSERT(parentWin);
+    parentWin->grabSpecialKeys(false);
   }
-#endif
+
+  grabSpecialKeys(true);
 
   /* symbian has a problem displaying maximized subwindows when the */
   /* parent window is fullscreen. Thus we force the child windows */
@@ -84,7 +84,7 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
   /* under meegos tablet ux the windows are entirely unmanaged and */
   /* always need this */
 
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MEEGO)
+#if defined(Q_OS_SYMBIAN)
   if(parent
 #ifdef Q_OS_SYMBIAN
      && parent->isFullScreen()
@@ -126,6 +126,7 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
     QMainWindow::setCentralWidget(vbox);
   }
 #endif
+
 }
 
 void CustomWindow::setCentralWidget(QWidget *widget) {
@@ -149,9 +150,14 @@ CustomWindow::~CustomWindow() {
   settings.endGroup();
 #endif
 
-#ifdef Q_OS_SYMBIAN
-  if(iInterfaceSelector) delete iInterfaceSelector;
-#endif
+  grabSpecialKeys(false);
+
+  if(parentWidget()) {
+    // parent widget must be a window
+    CustomWindow *parentWin = static_cast<CustomWindow *>(parentWidget());
+    Q_ASSERT(parentWin);
+    parentWin->grabSpecialKeys(true);
+  }
 
   if(m_iconLoader) delete m_iconLoader;
 }
@@ -194,6 +200,24 @@ void CustomWindow::keyPressEvent(QKeyEvent* event) {
   QWidget::keyPressEvent(event);
 }
 
+void CustomWindow::grabSpecialKeys(bool grab) {
+  qDebug() << __FUNCTION__ << m_name << grab;
+
+#ifdef Q_OS_SYMBIAN
+  if(grab) {
+    // under Symbian only one entity can grab the media keys. We let the map get them
+    QT_TRAP_THROWING(iInterfaceSelector = CRemConInterfaceSelector::NewL());
+    QT_TRAP_THROWING(iCoreTarget = CRemConCoreApiTarget::NewL(*iInterfaceSelector, *this));
+    iInterfaceSelector->OpenTargetL();
+  } else {
+    if(iInterfaceSelector) {
+      delete iInterfaceSelector;
+      iInterfaceSelector = NULL;
+    }
+  }
+#endif
+}
+
 #ifdef Q_OS_SYMBIAN
 // Callback when media keys are pressed
 void CustomWindow::MrccatoCommand(TRemConCoreApiOperationId aOperationId,
