@@ -3,7 +3,7 @@
 #include <QDebug>
 #include <QApplication>
 #include <QFile>
-#include <QDir>
+#include <QStringList>
 
 QString FileFinder::assembleFilename(const QStringList &parts) {
   Q_ASSERT(parts.size() > 1);
@@ -17,7 +17,7 @@ QString FileFinder::assembleFilename(const QStringList &parts) {
   }
 
   for(;i!=parts.end();i++)
-    fileName += QDir::separator() + *i;
+    fileName += "/" + *i;
 
   return fileName;
 }
@@ -37,8 +37,7 @@ QString FileFinder::find(const QString &type, const QString &name) {
     // local file does not exist, try system wide file
     if(!file.exists()) {
 #ifdef DATADIR
-      full = assembleFilename(QStringList(QDir::toNativeSeparators(DATADIR))
-			      << type << name);
+      full = assembleFilename(QStringList(DATADIR) << type << name);
       file.setFileName(full);
       if(!file.exists()) {
         qWarning() << __FUNCTION__ << "Unable to find file for " << name;
