@@ -132,6 +132,19 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   setCentralWidget(m_view);
 
   m_cacheProvider->start();
+
+#ifdef EXPIRATION_DATE
+  // create expiration timer if required
+  if(QDate::fromString(EXPIRATION_DATE, "ddMMyyyy") <=
+     QDate::currentDate()) {
+    statusMessage(tr("This copy of CacheMe has expired and will close in one minute!"));
+    QTimer::singleShot(60000, this, SLOT(close()));
+  } else {
+    statusMessage(tr("This copy of CacheMe will expire in %1 days!").
+		  arg(QDate::currentDate().daysTo(
+		  QDate::fromString(EXPIRATION_DATE, "ddMMyyyy"))));
+  }
+#endif  
 }
 
 MainWindow::~MainWindow() {
