@@ -36,7 +36,7 @@ class MainWindow : public CustomWindow {
 
  private slots:
   void about();
-  void mapdialog();
+  void settingsdialog();
   void showDetail(const Cache &);
 
  private:
