@@ -13,10 +13,11 @@ class MapWidget;
 class MapBannerEntry : public QObject {
   Q_OBJECT;
  public:
-  enum State { Appearing, Visible, Disappearing, Done };
+  enum State { Waiting, Appearing, Visible, Disappearing, Done };
   MapBannerEntry(MapWidget *, const QString &);
   ~MapBannerEntry();
-  void paint(QPainter *);
+  void paint(QPainter *, bool);
+  bool isDisappearing() const;
 
  private slots:
   void timeout();
@@ -34,7 +35,7 @@ class MapBannerEntry : public QObject {
   MapWidget *m_mapWidget;
   static const int STEPS = 10;
   static const int APPEAR = 500;   // (dis-)appears in these msec
-  static const int STAY = 2000;    // stays these msec
+  static const int STAY = 3000;    // stays these msec
 };
 
 class MapBannerEntryList : public QList<MapBannerEntry*> {
