@@ -265,7 +265,9 @@ public:
       else
 	this->m_placedByStr = QString(QObject::tr("Placed by") + 
 				      " " + cache->owner());
-    }
+    } else if(cache->dateOfPlacement().isValid())
+      this->m_placedByStr = cache->dateOfPlacementString();
+	      
     this->m_containerStr = QString(QObject::tr("Container") + ":");
 
     // iconloader to load the icons used inside the bubble, default size
