@@ -115,6 +115,8 @@ void MapWidget::zoomIn() {
   } 
 }
 
+/* never call this method directly as it is bypassed on */
+/* e.g. maemo5. use emit showMessage() instead */
 void MapWidget::addBanner(const QString &msg) {
   this->m_mapBanner->message(msg);
 }
@@ -287,6 +289,8 @@ bool MapWidget::MapCacheObject::contains(const QGeoCoordinate &coo) const {
 }
 
 void MapWidget::updateCaches(const CacheList &cacheList) {
+  static bool tooOld = false;
+
   // save cache if existing bubble
   Cache bubbleCache;
   if(m_bubble) bubbleCache = m_bubble->cache();
@@ -295,6 +299,16 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
   // remove all existing caches
   m_cacheGroup->clearChildObjects();
 
+  // determine cachelist age
+  int weekAge = cacheList.date().daysTo(QDate::currentDate())/7;
+  if(!cacheList.date().isValid()) weekAge = 0;
+
+  if(!tooOld && weekAge > 0) {
+    emit showMessage(tr("Displayed cache data is %1 weeks old!").arg(weekAge));
+    tooOld = true;
+  } else if(tooOld && weekAge == 0)
+    tooOld = false;
+
   // draw all new caches
   QList<Cache>::const_iterator i;
   for( i = cacheList.begin(); i != cacheList.end(); ++i ) 
