@@ -13,6 +13,8 @@
 #include "iconloader.h"
 
 #include "mapoverlay.h"
+#include "mapbanner.h"
+#include "mapspinner.h"
 #include "mapbubble.h"
 
 QTM_USE_NAMESPACE
@@ -34,13 +36,17 @@ class MapWidget : public QGraphicsGeoMap {
   void cacheClicked(const QString &);
   void detailClicked(const QString &);
   void showMessage(const QString &);
+  void fullscreen();
   
  public slots:
   void zoomIn();
   void zoomOut();
+  void toggleFullscreen();
   void gpsFollow();
   void showBubble(const Cache &);
   void showDetails();
+  void setBusy(bool);
+  void addBanner(const QString &);
   
  private slots:
   void reloadTimerExpired();
@@ -48,7 +54,7 @@ class MapWidget : public QGraphicsGeoMap {
   void zoomLevelChangedEvent(qreal);
   void centerChangedEvent(const QGeoCoordinate &);
   void positionUpdated(const QGeoPositionInfo &);
-
+  
  protected:
   void mousePressEvent(QGraphicsSceneMouseEvent *);
   void mouseReleaseEvent(QGraphicsSceneMouseEvent *);
@@ -66,10 +72,11 @@ class MapWidget : public QGraphicsGeoMap {
   // this should actually be much lower on non-touch devices
   static const int DRAG_FUZZ = 30;
   
-  int m_iconSize;
   QPointF m_downPos;
   IconLoader *m_iconLoader;
   MapOverlay *m_mapOverlay;
+  MapBanner *m_mapBanner;
+  MapSpinner *m_mapSpinner;
   QTimer *m_timer;
   MapBubble *m_bubble;
   QGeoBoundingBox m_currentViewport;
@@ -78,6 +85,10 @@ class MapWidget : public QGraphicsGeoMap {
   bool m_gpsLocked;
   int m_precisionAlpha;
 
+  // make sure map is only updated if it's dragged
+  // significantly
+  QGeoCoordinate m_lastUpdateCenter;
+
   QGeoMapPixmapObject *m_gpsMarker;
   QGeoMapCircleObject *m_gpsPrecision;
   QGeoMapGroupObject *m_cacheGroup;
