@@ -3,6 +3,7 @@
 
 #include <QDialog>
 #include <QComboBox>
+#include <QLineEdit>
 
 #include "cacheprovider.h"
 #include "mapwidget.h"
@@ -11,7 +12,7 @@ class SettingsDialog : public QDialog {
 Q_OBJECT
 
  public:
-  SettingsDialog(MapWidget *, CacheProvider *, QWidget *parent = 0);
+  SettingsDialog(MapWidget *, CacheProvider *, QWidget * = 0);
 
  private slots:
   void applyChanges();
@@ -20,6 +21,8 @@ Q_OBJECT
   MapWidget *m_mapWidget;
   QComboBox *m_typeCombo;
   QComboBox *m_serviceCombo;
+  QLineEdit *m_name;
+  QLineEdit *m_password;
 };
 
 #endif
